==> react-lds-8.7.0.tgz: package/es/components/Combobox/EntityCombobox.js <==
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.regexp.search";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import isEmpty from 'lodash-es/isEmpty';
import isObject from 'lodash-es/isObject';
import { InputRaw } from '../Form';
import { Icon } from '../Icon';
import ComboboxCore from './components/ComboboxCore';
import ComboboxListbox from './components/ComboboxListbox';
import { EntityDropdownItem, SearchIndicatorDropdownItem } from './components/DropdownItems';
import { itemTypeEntity } from './utils/constants';
import { makeInputAddHandler } from './utils/helpers';
export var defaultEntityComboboxInputRenderer = function defaultEntityComboboxInputRenderer(inputProps, opts) {
  var isMultiSelect = opts.isMultiSelect,
      makeSelectHandler = opts.makeSelectHandler,
      selectedItems = opts.selectedItems;

  var onKeyDown = inputProps.onKeyDown,
      value = inputProps.value,
      rest = _objectWithoutProperties(inputProps, ["onKeyDown", "value"]);

  var len = selectedItems.length;
  var hasSingleSelection = !isMultiSelect && len === 1;
  var inputValue = value;
  var activeId = null;
  var selectedItem;

  if (hasSingleSelection) {
    var _selectedItems = _slicedToArray(selectedItems, 1);

    selectedItem = _selectedItems[0];
    var _selectedItem = selectedItem,
        id = _selectedItem.id,
        label = _selectedItem.label;
    inputValue = label;
    activeId = id;
  }

  return React.createElement(InputRaw, _extends({}, rest, {
    "aria-activedescendant": !hasSingleSelection && activeId ? activeId : null,
    "aria-autocomplete": "list",
    className: "slds-input slds-combobox__input slds-combobox__input-value",
    iconLeft: selectedItem && React.createElement(Icon, {
      className: "slds-combobox__input-entity-icon",
      icon: selectedItem.icon.icon,
      sprite: selectedItem.icon.sprite
    }),
    iconRight: hasSingleSelection ? 'clear' : 'search',
    iconRightOnClick: hasSingleSelection ? makeSelectHandler(activeId) : null,
    onKeyDown: makeInputAddHandler(onKeyDown, opts),
    readOnly: hasSingleSelection,
    value: inputValue
  }));
}; // eslint-disable-next-line react/prop-types

export var defaultEntityComboboxItemRenderer = function defaultEntityComboboxItemRenderer(_ref, opts) {
  var id = _ref.id,
      resultProps = _objectWithoutProperties(_ref, ["id"]);

  var makeSelectHandler = opts.makeSelectHandler,
      search = opts.search,
      selectedItems = opts.selectedItems;
  return React.createElement(EntityDropdownItem, _extends({}, resultProps, {
    highlight: search,
    isMultiSelect: !isEmpty(selectedItems),
    key: id,
    id: id,
    onSelect: makeSelectHandler(id)
  }));
};
export var EntityCombobox =
/*#__PURE__*/
function (_Component) {
  _inherits(EntityCombobox, _Component);

  function EntityCombobox() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, EntityCombobox);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(EntityCombobox)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "onSearch", function (input) {
      var onSearch = _this.props.onSearch;
      var val = isObject(input) ? input.target.value : input;
      onSearch(val, {
        isClear: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onSelect", function (id, opts) {
      var _this$props = _this.props,
          onSearch = _this$props.onSearch,
          onSelect = _this$props.onSelect;
      onSelect(id, opts);
      onSearch('', {
        isClear: true
      });
    });

    _defineProperty(_assertThisInitialized(_this), "renderSearchIndicator", function () {
      var _this$props2 = _this.props,
          renderItemsPrepended = _this$props2.renderItemsPrepended,
          search = _this$props2.search;
      if (search.trim().length < 2) return null;
      return React.createElement(React.Fragment, null, renderItemsPrepended && renderItemsPrepended(), React.createElement(SearchIndicatorDropdownItem, {
        search: search
      }));
    });

    return _this;
  }

  _createClass(EntityCombobox, [{
    key: "render",
    value: function render() {
      return React.createElement(ComboboxCore, _extends({}, this.props, {
        isInlineListboxSelection: true,
        onSelect: this.onSelect,
        onSearch: this.onSearch,
        renderItemsPrepended: this.renderSearchIndicator
      }));
    }
  }]);

  return EntityCombobox;
}(Component);

_defineProperty(EntityCombobox, "defaultProps", {
  closeOnSelect: true,
  comboboxClassName: null,
  dropdownClassName: null,
  error: null,
  height: 5,
  hideErrorMessage: false,
  hideLabel: false,
  isLoading: false,
  isMultiSelect: false,
  isRequired: false,
  items: [],
  labelListbox: undefined,
  renderInput: defaultEntityComboboxInputRenderer,
  renderItem: defaultEntityComboboxItemRenderer,
  renderItemsAppended: null,
  renderItemsPrepended: null,
  renderListbox: function renderListbox(listboxProps) {
    return React.createElement(ComboboxListbox, listboxProps);
  },
  search: '',
  selectedItems: []
});

EntityCombobox.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * See `ComboboxCore` or the Storybook stories for more information
   */
  closeOnSelect: PropTypes.bool,
  comboboxClassName: PropTypes.string,
  dropdownClassName: PropTypes.string,
  error: PropTypes.string,
  height: PropTypes.oneOf([5, 7, 10]),
  hideErrorMessage: PropTypes.bool,
  hideLabel: PropTypes.bool,
  id: PropTypes.string.isRequired,
  isLoading: PropTypes.bool,
  isMultiSelect: PropTypes.bool,
  isRequired: PropTypes.bool,
  isOpen: PropTypes.bool.isRequired,
  label: PropTypes.node.isRequired,
  labelListbox: PropTypes.string,
  placeholder: PropTypes.string.isRequired,
  onToggle: PropTypes.func.isRequired,
  renderInput: PropTypes.func,
  renderItem: PropTypes.func,
  renderItemsAppended: PropTypes.func,
  renderItemsPrepended: PropTypes.func,
  renderListbox: PropTypes.func,
  search: PropTypes.string,
  items: PropTypes.arrayOf(itemTypeEntity),
  onSearch: PropTypes.func.isRequired,
  onSelect: PropTypes.func.isRequired,
  selectedItems: PropTypes.arrayOf(itemTypeEntity)
} : {};

==> react-lds-9.1.0.tgz: package/es/components/Combobox/EntityCombobox.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.exec";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/es.string.search";
import "core-js/modules/es.string.trim";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import isEmpty from 'lodash-es/isEmpty';
import isObject from 'lodash-es/isObject';
import { InputRaw } from '../Form';
import { Icon } from '../Icon';
import ComboboxCore from './components/ComboboxCore';
import ComboboxListbox from './components/ComboboxListbox';
import { EntityDropdownItem, SearchIndicatorDropdownItem } from './components/DropdownItems';
import { itemTypeEntity } from './utils/constants';
import { makeInputAddHandler } from './utils/helpers';
export var defaultEntityComboboxInputRenderer = function defaultEntityComboboxInputRenderer(inputProps, opts) {
  var isMultiSelect = opts.isMultiSelect,
      makeSelectHandler = opts.makeSelectHandler,
      selectedItems = opts.selectedItems;

  var onKeyDown = inputProps.onKeyDown,
      value = inputProps.value,
      rest = _objectWithoutProperties(inputProps, ["onKeyDown", "value"]);

  var len = selectedItems.length;
  var hasSingleSelection = !isMultiSelect && len === 1;
  var inputValue = value;
  var activeId = null;
  var selectedItem;

  if (hasSingleSelection) {
    var _selectedItems = _slicedToArray(selectedItems, 1);

    selectedItem = _selectedItems[0];
    var _selectedItem = selectedItem,
        id = _selectedItem.id,
        label = _selectedItem.label;
    inputValue = label;
    activeId = id;
  }

  return React.createElement(InputRaw, _extends({}, rest, {
    "aria-activedescendant": !hasSingleSelection && activeId ? activeId : null,
    "aria-autocomplete": "list",
    className: "slds-input slds-combobox__input slds-combobox__input-value",
    iconLeft: selectedItem && React.createElement(Icon, {
      className: "slds-combobox__input-entity-icon",
      icon: selectedItem.icon.icon,
      sprite: selectedItem.icon.sprite
    }),
    iconRight: hasSingleSelection ? 'clear' : 'search',
    iconRightOnClick: hasSingleSelection ? makeSelectHandler(activeId) : null,
    onKeyDown: makeInputAddHandler(onKeyDown, opts),
    readOnly: hasSingleSelection,
    value: inputValue
  }));
}; // eslint-disable-next-line react/prop-types

export var defaultEntityComboboxItemRenderer = function defaultEntityComboboxItemRenderer(_ref, opts) {
  var id = _ref.id,
      resultProps = _objectWithoutProperties(_ref, ["id"]);

  var makeSelectHandler = opts.makeSelectHandler,
      search = opts.search,
      selectedItems = opts.selectedItems;
  return React.createElement(EntityDropdownItem, _extends({}, resultProps, {
    highlight: search,
    isMultiSelect: !isEmpty(selectedItems),
    key: id,
    id: id,
    onSelect: makeSelectHandler(id)
  }));
};
export var EntityCombobox =
/*#__PURE__*/
function (_Component) {
  _inherits(EntityCombobox, _Component);

  function EntityCombobox() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, EntityCombobox);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(EntityCombobox)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "onSearch", function (input) {
      var onSearch = _this.props.onSearch;
      var val = isObject(input) ? input.target.value : input;
      onSearch(val, {
        isClear: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onSelect", function (id, opts) {
      var _this$props = _this.props,
          onSearch = _this$props.onSearch,
          onSelect = _this$props.onSelect;
      onSelect(id, opts);
      onSearch('', {
        isClear: true
      });
    });

    _defineProperty(_assertThisInitialized(_this), "renderSearchIndicator", function () {
      var _this$props2 = _this.props,
          renderItemsPrepended = _this$props2.renderItemsPrepended,
          search = _this$props2.search;
      if (search.trim().length < 2) return null;
      return React.createElement(React.Fragment, null, renderItemsPrepended && renderItemsPrepended(), React.createElement(SearchIndicatorDropdownItem, {
        search: search
      }));
    });

    return _this;
  }

  _createClass(EntityCombobox, [{
    key: "render",
    value: function render() {
      return React.createElement(ComboboxCore, _extends({}, this.props, {
        isInlineListboxSelection: true,
        onSelect: this.onSelect,
        onSearch: this.onSearch,
        renderItemsPrepended: this.renderSearchIndicator
      }));
    }
  }]);

  return EntityCombobox;
}(Component);

_defineProperty(EntityCombobox, "defaultProps", {
  closeOnSelect: true,
  comboboxClassName: null,
  dropdownClassName: null,
  error: null,
  height: 5,
  hideErrorMessage: false,
  hideLabel: false,
  isLoading: false,
  isMultiSelect: false,
  isRequired: false,
  items: [],
  labelListbox: undefined,
  renderInput: defaultEntityComboboxInputRenderer,
  renderItem: defaultEntityComboboxItemRenderer,
  renderItemsAppended: null,
  renderItemsPrepended: null,
  renderListbox: function renderListbox(listboxProps) {
    return React.createElement(ComboboxListbox, listboxProps);
  },
  search: '',
  selectedItems: []
});

EntityCombobox.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * See `ComboboxCore` or the Storybook stories for more information
   */
  closeOnSelect: PropTypes.bool,
  comboboxClassName: PropTypes.string,
  dropdownClassName: PropTypes.string,
  error: PropTypes.string,
  height: PropTypes.oneOf([5, 7, 10]),
  hideErrorMessage: PropTypes.bool,
  hideLabel: PropTypes.bool,
  id: PropTypes.string.isRequired,
  isLoading: PropTypes.bool,
  isMultiSelect: PropTypes.bool,
  isRequired: PropTypes.bool,
  isOpen: PropTypes.bool.isRequired,
  label: PropTypes.node.isRequired,
  labelListbox: PropTypes.string,
  placeholder: PropTypes.string.isRequired,
  onToggle: PropTypes.func.isRequired,
  renderInput: PropTypes.func,
  renderItem: PropTypes.func,
  renderItemsAppended: PropTypes.func,
  renderItemsPrepended: PropTypes.func,
  renderListbox: PropTypes.func,
  search: PropTypes.string,
  items: PropTypes.arrayOf(itemTypeEntity),
  onSearch: PropTypes.func.isRequired,
  onSelect: PropTypes.func.isRequired,
  selectedItems: PropTypes.arrayOf(itemTypeEntity)
} : {};
